/*****************************************************************************
 * cuckooo - OpenOffice.org nested in KDE                                    *
 *                                                                           *
 * Copyright (C) 2003 Jan Holesovsky <kendy@artax.karlin.mff.cuni.cz>        *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License         *
 * along with this program; if not, write to the Free Software               *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *****************************************************************************/

#include <kaction.h>
#include <kdebug.h>
#include <kfiledialog.h>
#include <klibloader.h>
#include <klocale.h>

#include "shell.h"

using namespace KOOo;

Shell::Shell()
{
  // Menus and toolbars
  setXMLFile( "cuckoooui.rc" );

  // Setup actions
  (void) new KAction(i18n("&Open..."), "fileopen", 0, this,
		     SLOT(slotFileOpen()), actionCollection(), "file_open");
  (void) new KAction(i18n("&Quit"), "exit", 0, this,
		     SLOT(close()), actionCollection(), "file_quit");

  // Try to find libcuckooo
#if 0
  KLibFactory *factory = KLibLoader::self()->factory("libcuckooo");
  if (factory)
#endif
  // We have to use globalLibrary() in order to have working exceptions
  KLibrary *lib = KLibLoader::self()->globalLibrary("libcuckooo");
  if (lib)
  {
    // Create the part
#if 0
    m_part = (KParts::ReadOnlyPart *) factory->create(this, "part",
#endif
    m_part = (KParts::ReadOnlyPart *) lib->factory()->create(this, "part",
	"KParts::ReadOnlyPart");
    // Set the main widget
    setCentralWidget(m_part->widget());
    // Integrate its GUI
    createGUI(m_part);
  }
  else
    kdFatal() << "libcuckooo not found!" << endl;
}

Shell::~Shell()
{
  delete m_part;
}

void Shell::openURL(const KURL &url)
{
  m_part->openURL(url);
}

void Shell::slotFileOpen(void)
{
  KURL url = KFileDialog::getOpenURL(m_workdir,
    i18n("*.sxc *.SXC *.stc *.STC "
           "*.sxd *.SXD *.std *.STD "
           "*.sxi *.SXI *.sti *.STI "
           "*.sxw *.SXW *.sxg *.SXG *.stw *.STW "
           "*.doc *.DOC *.dot *.DOT "
           "*.xls *.XLS *.xlc *.XLC *.xll *.XLL *.xlw *.XLW "
           "*.pps *.PPS *.ppz *.PPZ *.ppt *.PPT "
           "*.sdc *.SDC "
           "*.sda *.SDA "
           "*.sdd *.SDD "
           "*.sdw *.SDW *.sgl *.SGL|All Document Files\n"
         "*.sxc *.SXC *.stc *.STC|OpenOffice.org Calc Files\n"
         "*.sxd *.SXD *.std *.STD|OpenOffice.org Draw Files\n"
         "*.sxi *.SXI *.sti *.STI|OpenOffice.org Impress Files\n"
         "*.sxw *.SXW *.sxg *.SXG *.stw *.STW|OpenOffice.org Writer Files\n"
         "*.doc *.DOC *.dot *.DOT|MS Word Files\n"
	 "*.xls *.XLS *.xlc *.XLC *.xll *.XLL *.xlw *.XLW|MS Excel Files\n"
	 "*.pps *.PPS *.ppz *.PPZ *.ppt *.PPT|MS Powerpoint\n"
         "*.sdc *.SDC|StarCalc 5.0 Files\n"
         "*.sda *.SDA|StarDraw 5.0 Files\n"
         "*.sdd *.SDD|StarImpress 5.0 Files\n"
         "*.sdw *.SDW *.sgl *.SGL|StarWriter 5.0 Files"));

  if (!url.isEmpty())
    openURL(url);
}
